@@ -11,22 +11,17 @@ use std::{
     io::Write,
 };
 
-const HASH_FACTOR: f64 = 1_000_000.0;
+use crate::angle::Angle;
 
 /// Latitude in degrees, required be within the range -90.0 to 90.0
-#[derive(Into, Clone, Copy, Display, FromStr, Debug, Serialize, Deserialize)]
-#[serde(into = "f64", try_from = "f64")]
-pub struct Latitude(f64);
+#[derive(
+    Into, Clone, Copy, Display, FromStr, Debug, Serialize, Deserialize, PartialEq, Eq, Hash,
+)]
+pub struct Latitude(Angle);
 
-impl PartialEq for Latitude {
-    fn eq(&self, other: &Self) -> bool {
-        (self.0 * HASH_FACTOR) as i32 == (other.0 * HASH_FACTOR) as i32
-    }
-}
-
-impl Hash for Latitude {
-    fn hash<H: Hasher>(&self, state: &mut H) {
-        ((self.0 * HASH_FACTOR) as u32).hash(state);
+impl From<Latitude> for f64 {
+    fn from(item: Latitude) -> Self {
+        item.0.deg()
     }
 }
 
@@ -34,7 +29,7 @@ impl TryFrom<f64> for Latitude {
     type Error = Error;
     fn try_from(item: f64) -> Result<Self, Self::Error> {
         if item >= -90.0 && item <= 90.0 {
-            Ok(Self(item))
+            Ok(Self(Angle::from_deg(item)))
         } else {
             Err(format_err!("{} is not a valid latitude", item))
         }
@@ -50,7 +45,7 @@ mod test {
         hash::{Hash, Hasher},
     };
 
-    use crate::latitude::{Latitude, HASH_FACTOR};
+    use crate::latitude::Latitude;
 
     #[test]
     fn test_latitude() -> Result<(), Error> {
